import 'package:flutter/material.dart';

/// *
/// 编辑页或新增页
/// 1、输入框
/// 2、选择框（enabled = false）
Widget editText(
  String title, //字端key
  {
  bool isPassword = false, //是否是密码
  bool enabled = true, //能不能点击
  bool isRequired = false, //能不能点击
  String showText, //字端value
  String hintText, //hint提示
  Color color = const Color(0xfff3f3f4),
  TextInputType textInputType = TextInputType.text, //字端类型
  TextEditingController textEditingController, //若果是输入框需要传入
  Function() onTap, //点击事件
}) {
  return GestureDetector(
    onTap: () {
      onTap();
    },
    child: Container(
      decoration: BoxDecoration(
        color: color,
        borderRadius: BorderRadius.all(Radius.circular(5)),
      ),
      margin: EdgeInsets.only(top: 5),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Padding(
            padding: const EdgeInsets.only(
                left: 15.0, right: 8.0, top: 10.0, bottom: 8.0),
            child: Text(
              title + ':',
              style: TextStyle(fontSize: 18),
            ),
          ),
          enabled
              ? Expanded(
                  child: TextField(
                      maxLines: null,
                      enabled: enabled,
                      keyboardType: textInputType,
                      controller: textEditingController,
                      obscureText: isPassword,
                      style: TextStyle(
                          color: Colors.black.withOpacity(0.8), fontSize: 18.0),
                      decoration: InputDecoration(
                          hintText: hintText,
                          border: InputBorder.none,
                          fillColor: Colors.transparent,
                          filled: true)),
                )
              : Expanded(
                  child: Padding(
                    padding: const EdgeInsets.only(
                        right: 8.0, top: 10.0, bottom: 8.0),
                    child: RichText(
                      text: TextSpan(
                        text: showText,
                        style: TextStyle(
                            fontSize: 18,
                            color: showText == null || showText.contains('请')
                                ? Color(0xff707070)
                                : Color(0xff222831)),
                        children: [
                          TextSpan(
                            text: '日期',
                            style: TextStyle(
                                fontSize: 18, color: Color(0xfff3f3f4)),
                          ),
                        ],
                      ),
                    ),
                  ),
                ),
          Padding(
            padding: const EdgeInsets.only(
              right: 0.0,
              top: 12.0,
            ),
            child: Row(
              children: [
                Icon(
                  enabled == true ? null : Icons.chevron_right,
                  color: Colors.grey,
                ),
                isRequired
                    ? Text(
                        '* ',
                        style:
                            TextStyle(fontSize: 18, color: Color(0xffef4f4f)),
                      )
                    : Container(
                        width: 13,
                      )
              ],
            ),
          ), //设置图标为绿色
        ],
      ),
    ),
  );
}

/// 仅仅是展示文本（详情页）
Widget showText(String title, dynamic value,
    {bool isPassword = false,
    bool enabled = true,
    int maxLine = 100, //hint提示
    TextInputType textInputType = TextInputType.text,
    Function() onTap, //点击事件
    dynamic state}) {
  return GestureDetector(
    onTap: () {
      onTap();
    },
    child: Container(
      // padding: EdgeInsets.symmetric(horizontal: 10),
      child: Container(
        decoration: BoxDecoration(
          color: Color(0xffffffff),
          borderRadius: BorderRadius.all(Radius.circular(5)),
        ),
        margin: EdgeInsets.symmetric(vertical: 1),
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Expanded(
                  flex: 2,
                  child: Padding(
                    padding: const EdgeInsets.only(
                        left: 15.0, right: 8.0, top: 10.0, bottom: 8.0),
                    child: Text(
                      title + ':',
                      style: TextStyle(
                        fontSize: 18,
                        letterSpacing: 1,
                      ),
                    ),
                  ),
                ),
                Expanded(
                  flex: 3,
                  child: Padding(
                    padding:
                        const EdgeInsets.only(right: 8.0, top: 14.0, bottom: 8),
                    child: Text(
                      value == null ? '' : value.toString(),
                      textAlign: TextAlign.left,
                      maxLines: maxLine,
                      style: TextStyle(letterSpacing: 1, fontSize: 17.0),
                    ),
                  ),
                ),
              ],
            ),
            Container(
              color: Color(0xfff5f5f5),
              height: 1,
              width: double.infinity,
            ),
          ],
        ),
      ),
    ),
  );
}
